@@ -23,7 +23,7 @@ from allianceauth.notifications import notify
 from allianceauth.services.hooks import get_extension_logger
 from app_utils.datetime import DATETIME_FORMAT
 from app_utils.helpers import chunks
-from app_utils.logging import LoggerAddTag, make_logger_prefix
+from app_utils.logging import LoggerAddTag
 
 from .. import __title__, constants
 from ..app_settings import (
@@ -42,7 +42,7 @@ from ..helpers.esi_fetch import esi_fetch, esi_fetch_with_localization
 from ..managers import OwnerAssetManager
 from .eveuniverse import EveMoon, EvePlanet, EveSolarSystem, EveType, EveUniverse
 from .notifications import EveEntity, Notification, NotificationType
-from .structures import Structure
+from .structures import PocoDetails, Structure
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
@@ -93,7 +93,7 @@ class Owner(models.Model):
         ),
         (ERROR_UNKNOWN, "Unknown error"),
     ]
-
+    # PK
     corporation = models.OneToOneField(
         EveCorporationInfo,
         primary_key=True,
@@ -101,6 +101,19 @@ class Owner(models.Model):
         related_name="structure_owner",
         help_text="Corporation owning structures",
     )
+    # regular
+    are_pocos_public = models.BooleanField(
+        default=False,
+        help_text=("whether pocos of this owner are shown on public POCO page"),
+    )
+    assets_last_error = models.IntegerField(
+        choices=ERRORS_LIST,
+        default=ERROR_NONE,
+        help_text="error that occurred at the last sync atttempt (if any)",
+    )
+    assets_last_sync = models.DateTimeField(
+        null=True, default=None, blank=True, help_text="when the last sync happened"
+    )
     character = models.ForeignKey(
         CharacterOwnership,
         on_delete=models.SET_DEFAULT,
@@ -110,26 +123,7 @@ class Owner(models.Model):
         related_name="+",
         help_text="character used for syncing structures",
     )
-    structures_last_sync = models.DateTimeField(
-        null=True, default=None, blank=True, help_text="when the last sync happened"
-    )
-    structures_last_error = models.IntegerField(
-        choices=ERRORS_LIST,
-        default=ERROR_NONE,
-        help_text="error that occurred at the last sync atttempt (if any)",
-    )
-    assets_last_sync = models.DateTimeField(
-        null=True, default=None, blank=True, help_text="when the last sync happened"
-    )
-    assets_last_error = models.IntegerField(
-        choices=ERRORS_LIST,
-        default=ERROR_NONE,
-        help_text="error that occurred at the last sync atttempt (if any)",
-    )
-    notifications_last_sync = models.DateTimeField(
-        null=True, default=None, blank=True, help_text="when the last sync happened"
-    )
-    notifications_last_error = models.IntegerField(
+    forwarding_last_error = models.IntegerField(
         choices=ERRORS_LIST,
         default=ERROR_NONE,
         help_text="error that occurred at the last sync atttempt (if any)",
@@ -137,16 +131,12 @@ class Owner(models.Model):
     forwarding_last_sync = models.DateTimeField(
         null=True, default=None, blank=True, help_text="when the last sync happened"
     )
-    forwarding_last_error = models.IntegerField(
-        choices=ERRORS_LIST,
-        default=ERROR_NONE,
-        help_text="error that occurred at the last sync atttempt (if any)",
-    )
-    webhooks = models.ManyToManyField(
-        "Webhook",
-        default=None,
-        blank=True,
-        help_text="notifications are sent to these webhooks. ",
+    has_default_pings_enabled = models.BooleanField(
+        default=True,
+        help_text=(
+            "to enable or disable pinging of notifications for this owner "
+            "e.g. with @everyone and @here"
+        ),
     )
     is_active = models.BooleanField(
         default=True,
@@ -166,12 +156,13 @@ class Owner(models.Model):
             "the overall status of this services"
         ),
     )
-    has_default_pings_enabled = models.BooleanField(
-        default=True,
-        help_text=(
-            "to enable or disable pinging of notifications for this owner "
-            "e.g. with @everyone and @here"
-        ),
+    notifications_last_sync = models.DateTimeField(
+        null=True, default=None, blank=True, help_text="when the last sync happened"
+    )
+    notifications_last_error = models.IntegerField(
+        choices=ERRORS_LIST,
+        default=ERROR_NONE,
+        help_text="error that occurred at the last sync atttempt (if any)",
     )
     ping_groups = models.ManyToManyField(
         Group,
@@ -179,6 +170,20 @@ class Owner(models.Model):
         blank=True,
         help_text="Groups to be pinged for each notification - ",
     )
+    structures_last_error = models.IntegerField(
+        choices=ERRORS_LIST,
+        default=ERROR_NONE,
+        help_text="error that occurred at the last sync atttempt (if any)",
+    )
+    structures_last_sync = models.DateTimeField(
+        null=True, default=None, blank=True, help_text="when the last sync happened"
+    )
+    webhooks = models.ManyToManyField(
+        "Webhook",
+        default=None,
+        blank=True,
+        help_text="notifications are sent to these webhooks. ",
+    )
 
     def __str__(self) -> str:
         return str(self.corporation.corporation_name)
@@ -269,7 +274,6 @@ class Owner(models.Model):
     def update_structures_esi(self, user: User = None):
         """updates all structures from ESI"""
 
-        add_prefix = self._logger_prefix()
         try:
             token, error = self.token()
             if error:
@@ -279,49 +283,24 @@ class Owner(models.Model):
                 raise TokenError(self.to_friendly_error_message(error))
 
             try:
-                structures = self._fetch_upwell_structures(token)
+                structure_count = self._fetch_upwell_structures(token)
                 if STRUCTURES_FEATURE_CUSTOMS_OFFICES:
-                    structures += self._fetch_custom_offices(token)
+                    structure_count += self._fetch_custom_offices(token)
 
                 if STRUCTURES_FEATURE_STARBASES:
-                    structures += self._fetch_starbases(token)
+                    structure_count += self._fetch_starbases(token)
 
-                if structures:
+                if not structure_count:
                     logger.info(
-                        add_prefix(
-                            "Storing updates for {:,} structures".format(
-                                len(structures)
-                            )
-                        )
+                        "%s: This corporation does not appear to have any structures",
+                        self,
                     )
-                else:
-                    logger.info(
-                        add_prefix(
-                            "This corporation does not appear to have any structures"
-                        )
-                    )
-
-                # remove structures no longer returned from ESI
-                ids_local = {x.id for x in Structure.objects.filter(owner=self)}
-                ids_from_esi = {x["structure_id"] for x in structures}
-                ids_to_remove = ids_local - ids_from_esi
-                if len(ids_to_remove) > 0:
-                    Structure.objects.filter(id__in=ids_to_remove).delete()
-                    logger.info(
-                        "Removed {} structures which apparently no longer "
-                        "exist.".format(len(ids_to_remove))
-                    )
-                # update structures
-                for structure in structures:
-                    Structure.objects.update_or_create_from_dict(structure, self)
                 self.structures_last_error = self.ERROR_NONE
                 self.structures_last_sync = now()
                 self.save()
 
             except Exception as ex:
-                logger.exception(
-                    add_prefix("An unexpected error ocurred {}".format(ex))
-                )
+                logger.exception("%s: An unexpected error ocurred", self)
                 self.structures_last_error = self.ERROR_UNKNOWN
                 self.structures_last_sync = now()
                 self.save()
@@ -341,14 +320,26 @@ class Owner(models.Model):
 
         return success
 
-    def _fetch_upwell_structures(self, token: Token) -> list:
+    def _remove_structures_not_returned_from_esi(
+        self, structures_qs: models.QuerySet, new_structures: list
+    ):
+        """Remove structures no longer returned from ESI."""
+        ids_local = {x.id for x in structures_qs}
+        ids_from_esi = {x["structure_id"] for x in new_structures}
+        ids_to_remove = ids_local - ids_from_esi
+        if len(ids_to_remove) > 0:
+            structures_qs.filter(id__in=ids_to_remove).delete()
+            logger.info(
+                "Removed %d structures which apparently no longer exist.",
+                len(ids_to_remove),
+            )
+
+    def _fetch_upwell_structures(self, token: Token) -> int:
         """fetch Upwell structures from ESI for self"""
         from .eveuniverse import EsiNameLocalization
 
-        add_prefix = self._logger_prefix()
         corporation_id = self.corporation.corporation_id
         structures = list()
-
         try:
             # fetch all structures incl. localizations for services
             structures_w_lang = esi_fetch_with_localization(
@@ -357,7 +348,6 @@ class Owner(models.Model):
                 token=token,
                 languages=EsiNameLocalization.ESI_LANGUAGES,
                 has_pages=True,
-                logger_tag=add_prefix(),
             )
 
             # reduce data
@@ -367,13 +357,12 @@ class Owner(models.Model):
 
             # fetch additional information for structures
             if not structures:
-                logger.info(add_prefix("No Upwell structures retrieved from ESI"))
+                logger.info("%s: No Upwell structures retrieved from ESI", self)
             else:
                 logger.info(
-                    add_prefix(
-                        "Fetching additional infos for {} "
-                        "Upwell structures from ESI".format(len(structures))
-                    )
+                    "%s: Fetching additional infos for %d Upwell structures from ESI",
+                    self,
+                    len(structures),
                 )
                 for structure in structures:
                     try:
@@ -381,7 +370,6 @@ class Owner(models.Model):
                             "Universe.get_universe_structures_structure_id",
                             args={"structure_id": structure["structure_id"]},
                             token=token,
-                            logger_tag=add_prefix(),
                         )
                         structure["name"] = Structure.extract_name_from_esi_respose(
                             structure_info["name"]
@@ -394,14 +382,25 @@ class Owner(models.Model):
                             % (structure["structure_id"], ex)
                         )
                         structure["name"] = "(no data)"
+                logger.info(
+                    "%s: Storing updates for %d upwell structures",
+                    self,
+                    len(structures),
+                )
+                for structure in structures:
+                    Structure.objects.update_or_create_from_dict(structure, self)
 
             if STRUCTURES_DEVELOPER_MODE:
                 self._store_raw_data("structures", structures, corporation_id)
 
         except (HTTPError, ConnectionError):
-            logger.exception(add_prefix("Failed to fetch upwell structures"))
-
-        return structures
+            logger.exception("%s: Failed to fetch upwell structures", self)
+        else:
+            self._remove_structures_not_returned_from_esi(
+                structures_qs=self.structures.filter_upwell_structures(),
+                new_structures=structures,
+            )
+        return len(structures)
 
     @staticmethod
     def _compress_services_localization(
@@ -458,27 +457,27 @@ class Owner(models.Model):
                             service["name_" + lang] = name_loc
         return structures
 
-    def _fetch_custom_offices(self, token: Token) -> list:
+    def _fetch_custom_offices(self, token: Token) -> int:
         """fetch custom offices from ESI for self"""
-        add_prefix = self._logger_prefix()
+
         corporation_id = self.corporation.corporation_id
-        structures = list()
+        structures = dict()
         try:
             pocos = esi_fetch(
                 "Planetary_Interaction.get_corporations_corporation_id_customs_offices",
                 args={"corporation_id": corporation_id},
                 token=token,
                 has_pages=True,
-                logger_tag=add_prefix(),
             )
             if not pocos:
-                logger.info(add_prefix("No custom offices retrieved from ESI"))
+                logger.info("%s: No custom offices retrieved from ESI", self)
             else:
-                item_ids = [x["office_id"] for x in pocos]
+                pocos_2 = {row["office_id"]: row for row in pocos}
+                office_ids = list(pocos_2.keys())
                 positions = self._fetch_locations_for_pocos(
-                    corporation_id, item_ids, token
+                    corporation_id, office_ids, token
                 )
-                names = self._fetch_names_for_pocos(corporation_id, item_ids, token)
+                names = self._fetch_names_for_pocos(corporation_id, office_ids, token)
 
                 # making sure we have all solar systems loaded
                 # incl. their planets for later name matching
@@ -486,8 +485,7 @@ class Owner(models.Model):
                     EveSolarSystem.objects.get_or_create_esi(solar_system_id)
 
                 # compile pocos into structures list
-                for poco in pocos:
-                    office_id = poco["office_id"]
+                for office_id, poco in pocos_2.items():
                     planet_name = names.get(office_id, "")
                     if planet_name:
                         try:
@@ -523,24 +521,77 @@ class Owner(models.Model):
                     if office_id in positions:
                         structure["position"] = positions[office_id]
 
-                    structures.append(structure)
+                    structures[office_id] = structure
+
+                logger.info(
+                    "%s: Storing updates for %d customs offices", self, len(structure)
+                )
+                for office_id, structure in structures.items():
+                    structure_obj, _ = Structure.objects.update_or_create_from_dict(
+                        structure, self
+                    )
+                    try:
+                        poco = pocos_2[office_id]
+                    except KeyError:
+                        logger.warning(
+                            "%s: No details found for this POCO: %d", self, office_id
+                        )
+                    else:
+                        standing_level = PocoDetails.StandingLevel.from_esi(
+                            poco.get("standing_level")
+                        )
+                        PocoDetails.objects.update_or_create(
+                            structure=structure_obj,
+                            defaults={
+                                "alliance_tax_rate": poco.get("alliance_tax_rate"),
+                                "allow_access_with_standings": poco.get(
+                                    "allow_access_with_standings"
+                                ),
+                                "allow_alliance_access": poco.get(
+                                    "allow_alliance_access"
+                                ),
+                                "bad_standing_tax_rate": poco.get(
+                                    "bad_standing_tax_rate"
+                                ),
+                                "corporation_tax_rate": poco.get(
+                                    "corporation_tax_rate"
+                                ),
+                                "excellent_standing_tax_rate": poco.get(
+                                    "excellent_standing_tax_rate"
+                                ),
+                                "good_standing_tax_rate": poco.get(
+                                    "good_standing_tax_rate"
+                                ),
+                                "neutral_standing_tax_rate": poco.get(
+                                    "neutral_standing_tax_rate"
+                                ),
+                                "reinforce_exit_end": poco.get("reinforce_exit_end"),
+                                "reinforce_exit_start": poco.get(
+                                    "reinforce_exit_start"
+                                ),
+                                "standing_level": standing_level,
+                                "terrible_standing_tax_rate": poco.get(
+                                    "terrible_standing_tax_rate"
+                                ),
+                            },
+                        )
 
             if STRUCTURES_DEVELOPER_MODE:
                 self._store_raw_data("customs_offices", structures, corporation_id)
 
         except (HTTPError, ConnectionError):
-            logger.exception(add_prefix("Failed to fetch custom offices"))
+            logger.exception("%s: Failed to fetch custom offices", self)
+        else:
+            self._remove_structures_not_returned_from_esi(
+                structures_qs=self.structures.filter_customs_offices(),
+                new_structures=structures.values(),
+            )
 
-        return structures
+        return len(structures)
 
     def _fetch_locations_for_pocos(self, corporation_id, item_ids, token):
-        add_prefix = self._logger_prefix()
         logger.info(
-            add_prefix(
-                "Fetching locations for {} custom offices from ESI".format(
-                    len(item_ids)
-                )
-            )
+            "%s: Fetching locations for %d custom offices from ESI", self, len(item_ids)
         )
         locations_data = list()
         for item_ids_chunk in chunks(item_ids, 999):
@@ -551,20 +602,17 @@ class Owner(models.Model):
                     "item_ids": item_ids_chunk,
                 },
                 token=token,
-                logger_tag=add_prefix(),
             )
             locations_data += locations_data_chunk
         positions = {x["item_id"]: x["position"] for x in locations_data}
         return positions
 
     def _fetch_names_for_pocos(self, corporation_id, item_ids, token):
-        add_prefix = self._logger_prefix()
+
         logger.info(
-            add_prefix(
-                "Fetching names for {} custom office names from ESI".format(
-                    len(item_ids)
-                )
-            )
+            "%s: Fetching names for %d custom office names from ESI",
+            self,
+            len(item_ids),
         )
         names_data = list()
         for item_ids_chunk in chunks(item_ids, 999):
@@ -575,7 +623,6 @@ class Owner(models.Model):
                     "item_ids": item_ids_chunk,
                 },
                 token=token,
-                logger_tag=add_prefix(),
             )
             names_data += names_data_chunk
 
@@ -589,10 +636,9 @@ class Owner(models.Model):
         matches = reg_ex.match(text)
         return matches.group(1) if matches else ""
 
-    def _fetch_starbases(self, token: Token) -> list:
+    def _fetch_starbases(self, token: Token) -> int:
         """Fetch starbases from ESI for self."""
 
-        add_prefix = self._logger_prefix()
         structures = list()
         corporation_id = self.corporation.corporation_id
         try:
@@ -601,11 +647,9 @@ class Owner(models.Model):
                 args={"corporation_id": corporation_id},
                 token=token,
                 has_pages=True,
-                logger_tag=add_prefix(),
             )
-
             if not starbases:
-                logger.info(add_prefix("No starbases retrieved from ESI"))
+                logger.info("%s: No starbases retrieved from ESI", self)
             else:
                 names = self._fetch_starbases_names(corporation_id, starbases, token)
                 for starbase in starbases:
@@ -642,20 +686,28 @@ class Owner(models.Model):
 
                     structures.append(structure)
 
+                logger.info(
+                    "%s: Storing updates for %d starbases", self, len(structures)
+                )
+                for structure in structures:
+                    Structure.objects.update_or_create_from_dict(structure, self)
+
             if STRUCTURES_DEVELOPER_MODE:
                 self._store_raw_data("starbases", structures, corporation_id)
 
         except (HTTPError, ConnectionError):
-            logger.exception(add_prefix("Failed to fetch starbases"))
-
-        return structures
+            logger.exception("%s: Failed to fetch starbases")
+        else:
+            self._remove_structures_not_returned_from_esi(
+                structures_qs=self.structures.filter_starbases(),
+                new_structures=structures,
+            )
+        return len(structures)
 
     def _fetch_starbases_names(self, corporation_id, starbases, token):
-        add_prefix = self._logger_prefix()
+
         logger.info(
-            add_prefix(
-                "Fetching names for {} starbases from ESI".format(len(starbases))
-            )
+            "%s: Fetching names for %d starbases from ESI", self, len(starbases)
         )
         item_ids = [x["starbase_id"] for x in starbases]
         names_data = list()
@@ -667,7 +719,6 @@ class Owner(models.Model):
                     "item_ids": item_ids_chunk,
                 },
                 token=token,
-                logger_tag=add_prefix(),
             )
             names_data += names_data_chunk
         names = {x["item_id"]: x["name"] for x in names_data}
@@ -681,7 +732,7 @@ class Owner(models.Model):
         return names
 
     def _calc_starbase_fuel_expires(self, corporation_id, starbase, token):
-        add_prefix = self._logger_prefix()
+
         fuel_expires_at = None
         if starbase["state"] != "offline":
             starbase_details = esi_fetch(
@@ -692,7 +743,6 @@ class Owner(models.Model):
                     "system_id": starbase["system_id"],
                 },
                 token=token,
-                logger_tag=add_prefix(),
             )
             fuel_quantity = None
             if "fuels" in starbase_details:
@@ -773,12 +823,11 @@ class Owner(models.Model):
 
     def _fetch_notifications_from_esi(self, token: Token) -> dict:
         """fetching all notifications from ESI for current owner"""
-        add_prefix = self._logger_prefix()
+
         notifications = esi_fetch(
             "Character.get_characters_character_id_notifications",
             args={"character_id": self.character.character.character_id},
             token=token,
-            logger_tag=add_prefix(),
         )
         if STRUCTURES_DEVELOPER_MODE:
             self._store_raw_data(
@@ -787,11 +836,9 @@ class Owner(models.Model):
         if STRUCTURES_NOTIFICATIONS_ARCHIVING_ENABLED:
             self._store_raw_notifications(notifications)
         logger.debug(
-            add_prefix(
-                "Processing {:,} notifications received from ESI".format(
-                    len(notifications)
-                )
-            )
+            "%s: Processing %d notifications received from ESI",
+            self,
+            len(notifications),
         )
         return notifications
 
@@ -922,7 +969,6 @@ class Owner(models.Model):
     def send_new_notifications(self, user: User = None) -> bool:
         """forwards all new notification for this owner to Discord"""
 
-        add_prefix = self._logger_prefix()
         notifications_count = 0
         try:
             try:
@@ -949,21 +995,20 @@ class Owner(models.Model):
                     if len(new_notifications) > 0:
                         new_notifications_count += len(new_notifications)
                         logger.info(
-                            add_prefix(
-                                "Found {} new notifications for webhook {}".format(
-                                    len(new_notifications), webhook
-                                )
-                            )
+                            "%s: Found %d new notifications for webhook %s",
+                            self,
+                            len(new_notifications),
+                            webhook,
                         )
                         notifications_count += self._send_notifications_to_webhook(
                             new_notifications, webhook
                         )
 
                 if active_webhooks_count == 0:
-                    logger.info(add_prefix("No active webhooks"))
+                    logger.info("%s: No active webhooks", self)
 
                 if new_notifications_count == 0:
-                    logger.info(add_prefix("No new notifications found"))
+                    logger.info("%s: No new notifications found", self)
 
                 self.forwarding_last_error = self.ERROR_NONE
                 self.forwarding_last_sync = now()
@@ -973,9 +1018,7 @@ class Owner(models.Model):
                 pass
 
             except Exception as ex:
-                logger.exception(
-                    add_prefix("An unexpected error ocurred {}".format(ex))
-                )
+                logger.exception("%s: An unexpected error ocurred", self)
                 self.forwarding_last_error = self.ERROR_UNKNOWN
                 self.forwarding_last_sync = now()
                 self.save()
@@ -1008,25 +1051,20 @@ class Owner(models.Model):
 
         return sent_count
 
-    def _logger_prefix(self):
-        """returns standard logger prefix function"""
-        return make_logger_prefix(self.corporation.corporation_ticker)
-
     def token(self) -> Token:
         """returns a valid Token for the owner"""
         token = None
         error = None
-        add_prefix = self._logger_prefix()
 
         # abort if character is not configured
         if self.character is None:
-            logger.error(add_prefix("No character configured to sync"))
+            logger.error("%s: No character configured to sync", self)
             error = self.ERROR_NO_CHARACTER
 
         # abort if character does not have sufficient permissions
         elif not self.character.user.has_perm("structures.add_structure_owner"):
             logger.error(
-                add_prefix("self character does not have sufficient permission to sync")
+                "%s: self character does not have sufficient permission to sync", self
             )
             error = self.ERROR_INSUFFICIENT_PERMISSIONS
 
@@ -1043,14 +1081,14 @@ class Owner(models.Model):
                     .first()
                 )
             except TokenInvalidError:
-                logger.error(add_prefix("Invalid token for fetching structures"))
+                logger.error("%s: Invalid token for fetching structures", self)
                 error = self.ERROR_TOKEN_INVALID
             except TokenExpiredError:
-                logger.error(add_prefix("Token expired for fetching structures"))
+                logger.error("%s: Token expired for fetching structures", self)
                 error = self.ERROR_TOKEN_EXPIRED
             else:
                 if not token:
-                    logger.error(add_prefix("No token found with sufficient scopes"))
+                    logger.error("%s: No token found with sufficient scopes", self)
                     error = self.ERROR_TOKEN_INVALID
 
         return token, error
@@ -1058,7 +1096,7 @@ class Owner(models.Model):
     def _send_report_to_user(
         self, topic: str, topic_count: int, success: bool, error_code, user
     ):
-        add_prefix = self._logger_prefix()
+
         try:
             if success:
                 message_details = "%(count)s %(topic)s synced." % {
@@ -1091,11 +1129,8 @@ class Owner(models.Model):
                 level="success" if success else "danger",
             )
         except Exception as ex:
-            logger.error(
-                add_prefix(
-                    "An unexpected error ocurred while trying to "
-                    + "report to user: {}".format(ex)
-                )
+            logger.exception(
+                "%s: An unexpected error ocurred while trying to report to user", self
             )
             if settings.DEBUG:
                 raise ex
@@ -1103,14 +1138,12 @@ class Owner(models.Model):
     @staticmethod
     def _store_raw_data(name: str, data: list, corporation_id: int):
         """store raw data for debug purposes"""
-        with open(
-            "{}_raw_{}.json".format(name, corporation_id), "w", encoding="utf-8"
-        ) as f:
+        with open(f"{name}_raw_{corporation_id}.json", "w", encoding="utf-8") as f:
             json.dump(data, f, cls=DjangoJSONEncoder, sort_keys=True, indent=4)
 
     def update_asset_esi(self, user: User = None):
         """Update all assets for owner where location_id is in the active structure list from esi"""
-        add_prefix = self._logger_prefix()
+
         try:
             token, error = self.token()
             if error:
@@ -1125,9 +1158,7 @@ class Owner(models.Model):
                     structure_ids, self.corporation.corporation_id, token
                 )
             except Exception as ex:
-                logger.exception(
-                    add_prefix("An unexpected error ocurred {}".format(ex))
-                )
+                logger.exception("%s: An unexpected error ocurred", self)
                 self.assets_last_error = self.ERROR_UNKNOWN
                 self.assets_last_sync = now()
                 self.save()
